@@ -262,6 +262,51 @@ update_check_kolab_schema () {
 	fi
 }
 
+# Bug #53313
+update_check_ox_schema () {
+	status=$(dpkg-query -W -f '${db:Status-Status}' "univention-ox-directory-integration" 2>/dev/null)
+	if [ "$status" = "installed" ]; then
+		if ! is_ucr_true "ox/master/42/registered_ldap_acls"; then
+			local convert_schema_script
+			case "$server_role" in
+				domaincontroller_master)
+					convert_schema_script="/usr/share/univention-server-master/reregister_ox_ldap_schema.sh"
+					;;
+				domaincontroller_backup)
+					convert_schema_script="/usr/share/univention-server-backup/reregister_ox_ldap_schema.sh"
+					;;
+				*)
+					return 0
+					;;
+			esac
+			echo " The package univention-ox-directory-integration is installed. This package is"
+			echo " incompatible with UCS 5.0-0."
+			echo
+			echo " As the package contains a LDAP schema extension, this extension (a) has to"
+			echo " registered in the LDAP database or (b) has to be removed before the update"
+			echo " to UCS 5.0 is possible."
+			echo
+			echo " (a) Register LDAP schema files from univention-ox-directory-integration:"
+			echo "     To register the LDAP schema, run the following commands:"
+			echo "     \"$convert_schema_script\""
+			echo
+			echo " or (b) Remove the LDAP schema extension:"
+			echo "        Please visit https://help.univention.com/t/6443 for how to remove LDAP schema extensions"
+			echo "        (remove all attributes and objectclasses from that schema from the LDAP database)."
+			echo
+			echo " After either a) or b) has been completed, the package has to be removed from this server:"
+			echo "  univention-remove --purge univention-ox-directory-integration"
+			return 1
+		else
+			echo " The package univention-ox-directory-integration is installed. This package is"
+			echo " incompatible with UCS 5.0-0."
+			echo
+			echo " The package has to be removed from this server:"
+			echo "  univention-remove --purge univention-ox-directory-integration"
+			return 1
+		fi
+	fi
+}
 
 # Bug #51955
 update_check_old_packages () {
@@ -289,6 +334,7 @@ update_check_old_packages () {
 		univention-printquota
 		univention-passwd-store
 		univention-corporate-client-schema
+		univention-ox-dependencies-master
 	)
 	for pkg in "${old[@]}"
 	do
@@ -720,6 +766,8 @@ update_check_architecture () {  # Bug #51972
 }
 
 update_check_samba_server_schannel () {  # Bug #49898
+	[ -x /usr/bin/testparm ] ||
+		return 0
 	server_schannel=$(testparm -sv 2>/dev/null | sed -n 's/\t*server schannel = //p')
 	if [ "$server_schannel" != "Yes" ]; then
 		echo "WARNING: Samba is configured with \"server schannel = ${server_schannel,,}\","
@@ -816,18 +864,15 @@ update_check_samba_tdb_size () {  # Bug #53212
 	for p in $(ldbsearch -H /var/lib/samba/private/sam.ldb  -b '@PARTITION' -s base partition | ldapsearch-wrapper | sed -n 's/partition: //p'); do
 		fpath="/var/lib/samba/private/${p#*:}"
 		if file -b "$fpath" | grep -q "^TDB database" && [ "$(stat -c %s "$fpath")" -gt 1950000000 ]; then
-			echo "WARNING: The Samba SAM database is very large. During update Samba will attempt to convert"
-			echo "         the database to a new index format. For that step Samba requires temporary duplication"
+			echo "WARNING: The Samba SAM database is very large. During update Samba will convert the database"
+			echo "         to a new database and index format. For that step Samba requires temporary duplication"
 			echo "         of the database content, which may result in an overflow of the maximal size of the tdb"
 			echo "         database of 4GB. This may result in Samba not starting after the update."
-			echo "         We are currently researching possible solutions for this technical limitation."
+			echo "         To avoid this and make Samba scale to even larger numbers of accounts re recommend"
+			echo "         to convert the SAM database key-value backend from TDB to LMDB. That's the technology"
+			echo "         that UCS uses for OpenLDAP and has shown an exceptional robustness and performance."
 			echo "         "
-			echo "         Currently we recommend to not update this system without first checking with"
-			echo "         a non-productive clone of the system. Otherwise Samba may need to be reprovisioned manually."
-			echo "         "
-			echo "         A similar situation happend during update from Samba 4.7 to Samba 4.10, so the techically"
-			echo "         demanding workaround described under https://help.univention.com/t/12492 may be an option,"
-			echo "         but it is still untested with Samba 4.13."
+			echo "         The article https://help.univention.com/t/18014 describes the required steps."
 			rc=1
 			break
 		fi
@@ -858,12 +903,6 @@ from univention.config_registry.handler import EXECUTE_TOKEN
 
 BASE_DIR = "/etc/univention/templates/files/"
 
-DENY_LIST = [
-	'/etc/univention/templates/files/etc/postgresql/9.1/main/pg_hba.conf.d/10-appcenter',
-	'/etc/univention/templates/files/var/www/ucs-overview/entries.json',
-	'/etc/univention/templates/files/usr/share/univention-management-console-frontend/entries.json',
-]
-
 def dpkg():
 	etc = {}
 	cmd_dpkg = ["dpkg", "-S", os.path.join(BASE_DIR, '*')]
@@ -882,6 +921,21 @@ def uninstalled(package):
 	return out.decode('UTF-8', 'replace').startswith('deinstall ')
 
 
+def get_registered_files():
+	files = []
+	registered_directory = '/etc/univention/templates/info/'
+	for f in os.listdir(registered_directory):
+		for line in open(os.path.join(registered_directory, f), 'r').readlines():
+			if line.startswith('File: '):
+				fn = line.replace('File: ', '').strip()
+				files.append(BASE_DIR + fn)
+			elif line.startswith('Subfile: '):
+				fn = line.replace('Subfile: ', '').strip()
+				files.append(BASE_DIR + fn)
+
+	return files
+
+
 def cleanup(tmpdir):
 	shutil.rmtree(tmpdir, True)
 
@@ -897,9 +951,10 @@ tempfiles = [
 		for filename in files
 	) if EXECUTE_TOKEN.search(open(path, 'rb').read())
 ]
+registered_files = get_registered_files()
 failed = []
 for ucr_config_file in tempfiles:
-	if ucr_config_file.endswith('.dpkg-new') or ucr_config_file.endswith('.dpkg-old') or ucr_config_file in DENY_LIST:
+	if ucr_config_file not in registered_files:
 		continue
 	with open(ucr_config_file, 'rb') as fd:
 		template = fd.read()
@@ -946,6 +1001,7 @@ for failed_template in failed:
 	if failed_template in packages:
 		print(' (package: %s)' % (packages[failed_template], ), end='')
 	print('')
+	print('See <https://help.univention.com/t/17948> for information on how to proceed with each template.')
 if failed:
 	exit(1)
 EOF
